@@ -171,7 +171,7 @@ def createPDUstring(number, msg, addr_type):
     octifiedmsg = octify(msg)
     number = resetnumber(number)
     octifiednumber = [ semi_octify(number[i:i+2]) for i in range(0, len(number), 2) ]
-        
+
     HEADER = 33
     FIRSTOCTETOFSMSDELIVERMSG = 10
     #ADDR_TYPE = 129 #unknown format
@@ -203,11 +203,11 @@ class SMS(object):
     def __init__(self, msg, number):
         if number.find("+") > -1:
           conv_number = number.replace('+', '')
-          addr_type = 129
+          addr_type = 132
 #        change ADDR_TYPE ?!? 129 = international, 4 = local
         else:
           conv_number = number
-          addr_type = 132
+          addr_type = 129
         self.pdustring = createPDUstring(conv_number, msg, addr_type)
         write_to_rtcomm(msg, number)
 
@@ -393,7 +393,7 @@ class MsgWindow(QMainWindow, Ui_MsgWindow):
         palette.setColor(QPalette.Normal, QPalette.Dark, Qt.lightGray);
         self.lcdNumberCharacterCount.setPalette(palette);
 
-    def on_pushButtonSend_released(self):
+    def on_pushButtonSend_pressed(self):
         text_sender = TextSender(ui.gv.opener, ui.gv.key)
         text_sender.text = self.plainTextEditMessage.toPlainText()
         
@@ -420,9 +420,9 @@ class MsgWindow(QMainWindow, Ui_MsgWindow):
                         self.plainTextEditStatus.appendPlainText(message + "Success!")
                     else:
                         self.plainTextEditStatus.appendPlainText(message + "Failed!!")
-                    time.sleep(5)
+                    time.sleep(30)
             i = i + 1
-            
+
         '''
         for contact in ui.contact_selector.get_contacts_list():
             number = contact[1].mobile
@@ -457,6 +457,10 @@ if __name__ == "__main__":
     import sys
     app = QtGui.QApplication(sys.argv)
     ui = MainWindow()
+    try:
+        ui.setAttribute(Qt.WA_Maemo5StackedWindow)
+    except:
+           pass
     ui.show()
     QTimer.singleShot(50, ui.load_config)
     sys.exit(app.exec_())
